@@ -1,12 +1,21 @@
 package Perinci::Object::Metadata;
 
-our $DATE = '2016-12-15'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2016-12-26'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use String::Trim::More qw(trim_blank_lines);
+
+# BEGIN COPY-PASTE FROM String::Trim::More
+sub __trim_blank_lines {
+    local $_ = shift;
+    return $_ unless defined;
+    s/\A(?:\n\s*)+//;
+    s/(?:\n\s*){2,}\z/\n/;
+    $_;
+}
+# END COPY-PASTE
 
 sub new {
     my ($class, $meta) = @_;
@@ -68,7 +77,7 @@ sub langprop {
                 my $has_nl = $v =~ s/\n\z//;
                 $v = "{$olang|$k->[0] $v}" . ($has_nl ? "\n" : "");
             }
-            $v = trim_blank_lines($v);
+            $v = __trim_blank_lines($v);
             last GET;
         }
     }
@@ -140,7 +149,7 @@ Perinci::Object::Metadata - Base class for Perinci::Object metadata classes
 
 =head1 VERSION
 
-This document describes version 0.26 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2016-12-15.
+This document describes version 0.27 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2016-12-26.
 
 =head1 METHODS
 
@@ -205,7 +214,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ob
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Object>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
 
 =head1 BUGS
 
